<?php

App::uses('EvFormBuilderAppModel', 'EvFormBuilder.Model');

class Question extends EvFormBuilderAppModel {

	public $belongsTo = [
		'QuestionType' => [
			'className' => 'EvFormBuilder.QuestionType',
		],
	];

	public $hasMany = [
		'QuestionResponse' => [
			'className' => 'EvFormBuilder.QuestionResponse',
		],
	];

	public $hasAndBelongsToMany = [
		'QuestionBlock' => [
			'className' => 'EvFormBuilder.QuestionBlock',
			'foreignKey' => 'question_id',
			'associationForeignKey' => 'question_block_id',
			'with' => 'EvFormBuilder.QuestionBlocksQuestion',
			'order' => 'QuestionBlocksQuestion.sequence',
		],
	];

	public $validate = [
		'name' => [
			'required' => [
				'rule' => ['notBlank'],
				'message' => 'The question name must not be blank.',
			],
		],
		'question_type_id' => [
			'required' => [
				'rule' => ['notBlank'],
				'message' => 'A question must have a question type.',
			],
		],
	];

/**
 * Get the list of questions for a drop down menu.
 *
 * @param array $query Array of query params.
 * @return array List of questions.
 */
	public function getForDropDown($query = array()) {
		$virtualFields = $this->virtualFields;

		$query = $this->addDropDownQueryParams($query);

		$dropdownResults = parent::getForDropDown($query);

		$this->virtualFields = $virtualFields;

		return $dropdownResults;
	}

/**
 * Query used to retrieve a record ready for edit.
 *
 * @param int   $id     ID of row to edit.
 * @param array $params The db query array.
 * @return array The found item.
 */
	public function readForEdit($id, $params = array()) {
		$params['contain'][] = 'QuestionType';

		return parent::readForEdit($id, $params);
	}
}
